@@ -4,9 +4,19 @@ from time import sleep
 
 import guilogger
 
-FORMATTER = logging.Formatter(fmt='%(levelname)1s | %(asctime)s | %(name)s | %(message)s', datefmt='%Y-%m-%d %H:%M:%S') 
+FORMATTER = logging.Formatter(
+    fmt="%(levelname)1s | %(asctime)s | %(name)s | %(message)s",
+    datefmt="%Y-%m-%d %H:%M:%S",
+)
 
-@guilogger.app(level=logging.INFO, formatter=FORMATTER, title="testing", max_steps=len(sys.argv)-1)
+
+@guilogger.app(
+    level=logging.INFO,
+    formatter=FORMATTER,
+    title="testing",
+    max_steps=len(sys.argv) - 1,
+    close_after=False,
+)
 def main(args=sys.argv[1:], *, log_handler):
     logger = logging.getLogger(__name__)
     logger.level = logging.INFO
@@ -17,14 +27,14 @@ def main(args=sys.argv[1:], *, log_handler):
         for arg in args:
             sleep(1)
             logger.info(f"Processing: {arg}")
-        logger.warning("watch out! " * 200)
-        raise ValueError("Boom! " * 200)
+        logger.warning("watch out! ")
+        raise ValueError("Boom! ")
     except Exception as e:
         logger.exception(e)
         raise e
-
-    guilogger.log_done(logger)
+    finally:
+        logger.done()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
